#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.RadiusCommand import RadiusCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckRadius(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckRadius', 'radius')
        self.__host = None
        self.__port = 1645
        self.__username = None
        self.__password = None
        self.__nas_id = None
        self.__nas_ip = None
        self.__config_file = None
        self.__expect = None
        self.__retries = 2
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('radius'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_username(self, username):
        ValueChecker.is_string(username)
        self.__username = username
        return self

    def get_username(self):
        return self.__username

    def set_password(self, password):
        ValueChecker.is_string(password)
        self.__password = password
        return self

    def get_password(self):
        return self.__password

    def set_nas_id(self, nas_id):
        ValueChecker.is_string(nas_id)
        self.__nas_id = nas_id
        return self

    def get_nas_id(self):
        return self.__nas_id

    def set_nas_ip(self, nas_ip):
        ValueChecker.is_string(nas_ip)
        self.__nas_ip = nas_ip
        return self

    def get_nas_ip(self):
        return self.__nas_ip

    def set_config_file(self, config_file):
        ValueChecker.is_string(config_file)
        self.__config_file = config_file
        return self

    def get_config_file(self):
        return self.__config_file

    def set_expect(self, expect):
        ValueChecker.is_string(expect)
        self.__expect = expect
        return self

    def get_expect(self):
        return self.__expect

    def set_retries(self, retries):
        ValueChecker.is_number(retries)
        self.__retries = retries
        return self

    def get_retries(self):
        return self.__retries

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckRadius(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('radius'):
            RadiusCommand.create('radius')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__config_file:
            raise Exception('You have to specify a config file for ' + self.get_id())
        if None is self.__username:
            raise Exception('You have to specify a username for ' + self.get_id())
        if None is self.__password:
            raise Exception('You have to specify a password for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.HttpCommand import HttpCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckHttp(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckHttp', 'http')
        self.__vhost = None
        self.__ip = None
        self.__port = None
        self.__use_ipv4 = False
        self.__use_ipv6 = False
        self.__ssl = False
        self.__ssl_protocol = None
        self.__sni = False
        self.__certificate = False
        self.__certificate_warning_days = 29
        self.__certificate_critical_days = 15
        self.__continue_after_certificate = False
        self.__client_cert = None
        self.__client_cert_key = None
        self.__expect = 'HTTP/1.1 200'
        self.__expect_header = None
        self.__expect_content = None
        self.__uri = "/"
        self.__post_data = None
        self.__method = None
        self.__no_body = False
        self.__max_age = None
        self.__content_type = None
        self.__linespan = False
        self.__regex = None
        self.__eregi = None
        self.__invert_regex = False
        self.__authorization = False
        self.__authorization_username = None
        self.__authorization_password = None
        self.__proxy_authorization = False
        self.__proxy_authorization_username = None
        self.__proxy_authorization_password = None
        self.__useragent = None
        self.__header = None
        self.__extended_perfdata = False
        self.__show_url = False
        self.__link = False
        self.__onredirect = None
        self.__pagesize = None
        self.__pagesize_min = None
        self.__pagesize_max = None
        self.__warning = 7
        self.__critical = 15
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('webserver'))

    def set_vhost(self, vhost):
        ValueChecker.is_string(vhost)
        self.__vhost = vhost

        return self

    def get_vhost(self):
        return self.__vhost

    def set_ip(self, ip):
        ValueChecker.is_string(ip)
        self.__ip = ip

        return self

    def get_ip(self):
        return self.__ip

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ssl(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__ssl = enabled
        return self

    def get_ssl(self):
        return self.__ssl

    def set_ssl_protocol(self, protocol):
        ValueChecker.is_string(protocol)
        self.__ssl_protocol = protocol
        return self

    def get_ssl_protocol(self):
        return self.__ssl_protocol

    def set_sni(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__sni = enabled
        return self

    def get_sni(self):
        return self.__sni

    def set_certificate_check(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__certificate = enabled
        return self

    def get_certificate_check(self):
        return self.__certificate

    def set_certificate_warning_days(self, days):
        ValueChecker.is_number(days)
        self.__certificate_warning_days = days
        return self

    def get_certificate_warning_days(self):
        return self.__certificate_warning_days

    def set_certificate_critical_days(self, days):
        ValueChecker.is_number(days)
        self.__certificate_critical_days = days
        return self

    def get_certificate_critical_days(self):
        return self.__certificate_critical_days

    def set_continue_after_certificate(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__continue_after_certificate = enabled
        return self

    def get_continue_after_certificate(self):
        return self.__continue_after_certificate

    def set_client_cert_file(self, path):
        ValueChecker.is_string(path)
        self.__client_cert = path
        return self

    def get_client_cert_file(self):
        return self.__client_cert

    def set_client_cert_key_file(self, path):
        ValueChecker.is_string(path)
        self.__client_cert_key = path
        return self

    def get_client_cert_key_file(self):
        return self.__client_cert_key

    def set_expect(self, expect):
        ValueChecker.is_string(expect)
        self.__expect = expect
        return self

    def get_expect(self):
        return self.__expect

    def set_expect_header(self, expect):
        ValueChecker.is_string(expect)
        self.__expect_header = expect
        return self

    def get_expect_header(self):
        return self.__expect_header

    def set_expect_content(self, expect):
        ValueChecker.is_string(expect)
        self.__expect_content = expect
        return self

    def get_expect_content(self):
        return self.__expect_content

    def set_uri(self, uri):
        ValueChecker.is_string(uri)
        self.__uri = uri
        return self

    def get_uri(self):
        return self.__uri

    def set_post_data(self, post_data):
        ValueChecker.is_string(post_data)
        self.__post_data = post_data
        return self

    def get_post_data(self):
        return self.__post_data

    def set_method(self, method):
        ValueChecker.is_http_method(method)
        self.__method = method
        return self

    def get_method(self):
        return self.__method

    def set_no_body(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__no_body = enabled
        return self

    def get_no_body(self):
        return self.__no_body

    def set_max_age(self, age):
        ValueChecker.is_number(age)
        self.__max_age = age
        return self

    def get_max_age(self):
        return self.__max_age

    def set_content_type(self, content_type):
        ValueChecker.is_string(content_type)
        self.__content_type = content_type
        return self

    def get_content_type(self):
        return self.__content_type

    def set_linespan(self, linespan):
        ValueChecker.is_bool(linespan)
        self.__linespan = linespan
        return self

    def get_linespan(self):
        return self.__linespan

    def set_regex(self, regex):
        ValueChecker.is_string(regex)
        self.__regex = regex
        return self

    def get_regex(self):
        return self.__regex

    def set_regex_case_insensitive(self, regex_case_insensitive):
        ValueChecker.is_string(regex_case_insensitive)
        self.__eregi = regex_case_insensitive
        return self

    def get_regex_case_insensitive(self):
        return self.__eregi

    def set_invert_regex(self, invert_regex):
        ValueChecker.is_bool(invert_regex)
        self.__invert_regex = invert_regex
        return self

    def get_invert_regex(self):
        return self.__invert_regex

    def set_authorization(self, username, password):
        ValueChecker.is_string(username)
        ValueChecker.is_string(password)
        self.__authorization = True
        self.__authorization_username = username
        self.__authorization_password = password
        return self

    def disable_authorization(self):
        self.__authorization = False

    def get_authorization(self):
        return {
            'enabled': self.__authorization,
            'username': self.__authorization_username,
            'password': self.__authorization_password
        }

    def set_proxy_authorization(self, username, password):
        ValueChecker.is_string(username)
        ValueChecker.is_string(password)
        self.__proxy_authorization = True
        self.__proxy_authorization_username = username
        self.__proxy_authorization_password = password
        return self

    def disable_proxy_authorization(self):
        self.__proxy_authorization = False
        return self

    def get_proxy_authorization(self):
        return {
            'enabled': self.__proxy_authorization,
            'username': self.__proxy_authorization_username,
            'password': self.__proxy_authorization_password
        }

    def set_useragent(self, agent):
        ValueChecker.is_string(agent)
        self.__useragent = agent
        return self

    def get_useragent(self):
        return self.__useragent

    def set_header(self, header):
        ValueChecker.is_array(header)
        self.__header = header
        return self

    def get_header(self):
        return self.__header

    def set_extended_perfdata(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__extended_perfdata = enabled
        return self

    def get_extended_perfdata(self):
        return self.__extended_perfdata

    def set_onredirect(self, onredirect):
        ValueChecker.is_string(onredirect)
        self.__onredirect = onredirect
        return self

    def get_onredirect(self):
        return self.__onredirect

    def set_pagesize(self, min, max):
        ValueChecker.is_number(min)
        ValueChecker.is_number(max)
        self.__pagesize_min = min
        self.__pagesize_max = max
        self.__pagesize = True
        return self

    def disable_pagesize(self):
        self.__pagesize = False
        return self

    def get_pagesize(self):
        return {
            'enabled': self.__pagesize,
            'min': self.__pagesize_min,
            'max': self.__pagesize_max
        }

    def set_warning_response_time(self, time):
        ValueChecker.is_number(time)
        self.__warning = time
        return self

    def get_warning_response_time(self):
        return self.__warning

    def set_critical_response_time(self, time):
        ValueChecker.is_number(time)
        self.__critical = time
        return self

    def get_critical_response_time(self):
        return self.__critical

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckHttp(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('http'):
            HttpCommand.create('http')

        return check

    def validate(self):
        if None is self.__vhost and None is self.__ip:
            raise Exception('You have to specify a vhost or ip for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.Icinga2Confgen.DenyTlsVersionCommand import DenyTlsVersionCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDenyTlsVersion(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDenyTlsVersion', 'deny_tls_version')
        self.__protocol = None
        self.__domain = None
        self.__address = None
        self.set_check_interval('6h')
        self.add_service_group(ServiceGroup.create('security'))
        self.add_service_group(ServiceGroup.create('webserver'))
        self.add_service_group(ServiceGroup.create('tls'))

    def set_protocol(self, number):
        ValueChecker.is_string(number)
        if number not in ['1.0', '1.1', '1.2', '1.3']:
            raise Exception('Protocol must be 1.0 | 1.1 | 1.2 | 1.3')
        self.__protocol = number
        return self

    def get_protocol(self):
        return self.__protocol

    def set_address(self, address):
        ValueChecker.is_string(address)
        self.__address = address
        return self

    def get_address(self):
        return self.__address

    def set_domain(self, number):
        ValueChecker.is_string(number)
        self.__domain = number
        return self

    def get_domain(self):
        return self.__domain

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDenyTlsVersion(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('deny_tls_version'):
            DenyTlsVersionCommand.create('deny_tls_version')

        return check

    def validate(self):
        if None is self.__domain:
            raise Exception('You have to specify a domain for ' + self.get_id())
        if None is self.__protocol:
            raise Exception('You have to specify a protocol for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

setup_args = dict(
    name='icinga2confgen',
    version='0.0.4',
    description='Icinga2 configuration file generator for hosts, commands, checks, ... in python',
    long_description_content_type="text/markdown",
    long_description=README,
    license='AGPLv3',
    packages=find_packages(),
    author='Fabian Fröhlich',
    author_email='mail@confgen.org',
    keywords=['icinga', 'icinga2', 'icinga2-configuration', 'icinga2-plugin', 'configuration',
              'configuration-management', 'monitoring', 'check', 'nagios', 'nagios-plugin', 'nrpe', 'healthcheck',
              'serverstatus', 'security', 'security-tools'],
    url='https://github.com/f-froehlich/icinga2-config-generator',
    download_url='https://pypi.org/project/icinga2confgen/'

)

install_requires = [
    'tqdm',
]

if __name__ == '__main__':
    setup(**setup_args, install_requires=install_requires)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.DNSSECExpireCommand import DNSSECExpireCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDNSSECExpire(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDNSSECExpire', 'dnssec_expiry')
        self.__warning = '10d'
        self.__critical = '5d'
        self.__zone = None
        self.__resolver = '1.1.1.1'
        self.__failing_domain = None
        self.__record_type = None
        self.set_check_interval('3h')
        self.add_service_group(ServiceGroup.create('security'))
        self.add_service_group(ServiceGroup.create('dns'))
        self.add_service_group(ServiceGroup.create('dnssec'))

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_zone(self, zone):
        ValueChecker.is_string(zone)
        self.__zone = zone
        return self

    def get_zone(self):
        return self.__zone

    def set_resolver(self, resolver):
        ValueChecker.is_string(resolver)
        self.__resolver = resolver
        return self

    def get_resolver(self):
        return self.__resolver

    def set_failing_domain(self, failing_domain):
        ValueChecker.is_string(failing_domain)
        self.__failing_domain = failing_domain
        return self

    def get_failing_domain(self):
        return self.__failing_domain

    def set_record_type(self, record_type):
        ValueChecker.is_string(record_type)
        self.__record_type = record_type
        return self

    def get_record_type(self):
        return self.__record_type

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDNSSECExpire(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('dnssec_expiry'):
            DNSSECExpireCommand.create('dnssec_expiry')

        return check

    def validate(self):
        if None is self.__zone:
            raise Exception('You have to specify a zone for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.SMTPCommand import SMTPCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSMTP(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSMTP', 'smtp')
        self.__host = None
        self.__port = 25
        self.__use_ipv4 = False
        self.__use_ipv6 = False
        self.__expect = None
        self.__command = None
        self.__response = None
        self.__from = None
        self.__fqdn = None
        self.__cert_warning = 29
        self.__cert_critical = 15
        self.__cert = True
        self.__starttls = False
        self.__authtype = None
        self.__authuser = None
        self.__authpass = None
        self.__ignore_quit_failure = False
        self.__warning = 5
        self.__critical = 9
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('smtp'))
        self.add_service_group(ServiceGroup.create('mail'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_use_ipv4(self, use_ipv4):
        ValueChecker.is_bool(use_ipv4)
        self.__use_ipv4 = use_ipv4
        return self

    def get_use_ipv4(self):
        return self.__use_ipv4

    def set_use_ipv6(self, use_ipv6):
        ValueChecker.is_bool(use_ipv6)
        self.__use_ipv6 = use_ipv6
        return self

    def get_use_ipv6(self):
        return self.__use_ipv6

    def set_expect(self, expect):
        ValueChecker.is_string(expect)
        self.__expect = expect
        return self

    def get_expect(self):
        return self.__expect

    def set_command(self, command):
        ValueChecker.is_string(command)
        self.__command = command
        return self

    def get_command(self):
        return self.__command

    def set_response(self, response):
        ValueChecker.is_string(response)
        self.__response = response
        return self

    def get_response(self):
        return self.__response

    def set_fqdn(self, fqdn):
        ValueChecker.is_string(fqdn)
        self.__fqdn = fqdn
        return self

    def get_fqdn(self):
        return self.__fqdn

    def set_cert_warning(self, cert_warning):
        ValueChecker.is_number(cert_warning)
        self.__cert_warning = cert_warning
        return self

    def get_cert_warning(self):
        return self.__cert_warning

    def set_cert_critical(self, cert_critical):
        ValueChecker.is_number(cert_critical)
        self.__cert_critical = cert_critical
        return self

    def get_cert_critical(self):
        return self.__cert_critical

    def set_cert(self, cert):
        ValueChecker.is_bool(cert)
        self.__cert = cert
        return self

    def get_cert(self):
        return self.__cert

    def set_starttls(self, starttls):
        ValueChecker.is_bool(starttls)
        self.__starttls = starttls
        return self

    def get_starttls(self):
        return self.__starttls

    def set_authtype(self, authtype):
        ValueChecker.is_string(authtype)
        self.__authtype = authtype
        return self

    def get_authtype(self):
        return self.__authtype

    def set_authuser(self, authuser):
        ValueChecker.is_string(authuser)
        self.__authuser = authuser
        return self

    def get_authuser(self):
        return self.__authuser

    def set_authpass(self, authpass):
        ValueChecker.is_string(authpass)
        self.__authpass = authpass
        return self

    def get_authpass(self):
        return self.__authpass

    def set_ignore_quit_failure(self, ignore_quit_failure):
        ValueChecker.is_bool(ignore_quit_failure)
        self.__ignore_quit_failure = ignore_quit_failure
        return self

    def get_ignore_quit_failure(self):
        return self.__ignore_quit_failure

    def set_warning(self, warning):
        ValueChecker.is_number(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_number(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSMTP(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('smtp'):
            SMTPCommand.create('smtp')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.Utils.DefaultLocalChecks import DefaultLocalChecks
from icinga2confgen.ValueChecker import ValueChecker


class DefaultLocalMailserverChecks(DefaultLocalChecks):

    def __init__(self, servers=[], notifications=[], sudoers=[], additional_users=[]):
        DefaultLocalChecks.__init__(self, servers, notifications, sudoers, additional_users)
        self.__check_amavisd_running = True
        self.__check_dovecot_running = True
        self.__check_postgrey_running = True
        self.__check_opendkim_running = True
        self.__inherit = True
        DefaultLocalChecks.check_freshclam_running(self, True)
        DefaultLocalChecks.check_clamd_running(self, True)
        DefaultLocalChecks.check_postfix_running(self, True)

    def set_inherit(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inherit = enabled

        return self

    def is_inherit(self):
        return self.__inherit

    def check_amavisd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_amavisd_running = enabled

        return self

    def is_checking_amavisd_running(self):
        return self.__check_amavisd_running

    def check_dovecot_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_dovecot_running = enabled

        return self

    def is_checking_dovecot_running(self):
        return self.__check_dovecot_running

    def check_postgrey_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_postgrey_running = enabled

        return self

    def is_checking_postgrey_running(self):
        return self.__check_postgrey_running

    def check_opendkim_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_opendkim_running = enabled

        return self

    def is_checking_opendkim_running(self):
        return self.__check_opendkim_running

    def apply(self):
        if self.__inherit:
            DefaultLocalChecks.apply(self)

        for server in DefaultLocalChecks.get_server(self):
            if True is self.__check_amavisd_running:
                check = self.create_running_check_arguments('amavisd', 'amavisd', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is self.__check_dovecot_running:
                check = self.create_running_check('dovecot', 'dovecot', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is self.__check_postgrey_running:
                check = self.create_running_check('postgrey', 'postgrey', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is self.__check_opendkim_running:
                check = self.create_running_check('opendkim', 'opendkim', server)
                check.add_service_group(ServiceGroup.create('mail'))

            # force checking if enabled and not inherited
            if True is DefaultLocalChecks.is_checking_postfix_running(self) and not self.__inherit:
                check = self.create_running_check_arguments('postfix', 'postfix', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is DefaultLocalChecks.is_checking_freshclam_running(self) and not self.__inherit:
                check = self.create_running_check('freshclam', 'freshclam', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))

            if True is DefaultLocalChecks.is_checking_clamd_running(self) and not self.__inherit:
                check = self.create_running_check('clamd', 'clamd', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.UptimeCommand import UptimeCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckUptime(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckUptime', 'uptime')
        self.__warning = None
        self.__critical = None
        self.__for = None
        self.__since = None
        self.set_check_interval('15m')
        self.add_service_group(ServiceGroup.create('uptime'))
        self.add_service_group(ServiceGroup.create('system_health'))

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_since(self, since):
        ValueChecker.is_string(since)
        self.__since = since
        return self

    def get_since(self):
        return self.__since

    def set_for(self, time):
        ValueChecker.is_string(time)
        self.__for = time
        return self

    def get_for(self):
        return self.__for

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckUptime(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('uptime'):
            UptimeCommand.create('uptime')

        return check

    def validate(self):
        if None is self.__warning:
            raise Exception('You have to specify a warning for ' + self.get_id())
        if None is self.__critical:
            raise Exception('You have to specify a critical for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.OS.OS import OS
from icinga2confgen.PackageManager.PackageManager import apt


def os_debian_2_0(): return OS.create('debian_2_0').set_distro('debian').set_version('2.0').set_os(
    'Debian GNU/Linux 2.0 (hamm)').append_package_manager(apt())


def os_debian_2_1(): return OS.create('debian_2_1').set_distro('debian').set_version('2.1').set_os(
    'Debian GNU/Linux 2.1 (slink)').append_package_manager(apt())


def os_debian_2_2(): return OS.create('debian_2_2').set_distro('debian').set_version('2.2').set_os(
    'Debian GNU/Linux 2.2 (potato)').append_package_manager(apt())


def os_debian_3_0(): return OS.create('debian_3_0').set_distro('debian').set_version('3.0').set_os(
    'Debian GNU/Linux 3.0 (woody)').append_package_manager(apt())


def os_debian_3_1(): return OS.create('debian_3_1').set_distro('debian').set_version('3.1').set_os(
    'Debian GNU/Linux 3.1 (sarge)').append_package_manager(apt())


def os_debian_4_0(): return OS.create('debian_4_0').set_distro('debian').set_version('4.0').set_os(
    'Debian GNU/Linux 4.0 (etch)').append_package_manager(apt())


def os_debian_5_0(): return OS.create('debian_5_0').set_distro('debian').set_version('5.0').set_os(
    'Debian GNU/Linux 5.0 (lenny)').append_package_manager(apt())


def os_debian_6_0(): return OS.create('debian_6_0').set_distro('debian').set_version('6.0').set_os(
    'Debian 6.0 (squeeze)').append_package_manager(apt())


def os_debian_7(): return OS.create('debian_7').set_distro('debian').set_version('7').set_os(
    'Debian 7 (wheezy)').append_package_manager(apt())


def os_debian_8(): return OS.create('debian_8').set_distro('debian').set_version('8').set_os(
    'Debian 8 (jessie)').append_package_manager(apt())


def os_debian_9(): return OS.create('debian_9').set_distro('debian').set_version('9').set_os(
    'Debian 9 (stretch)').append_package_manager(apt())


def os_debian_10(): return OS.create('debian_10').set_distro('debian').set_version('10').set_os(
    'Debian 10 (buster)').append_package_manager(apt())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.DigCommand import DigCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDig(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDig', 'dig')
        self.__warning_time = 5
        self.__critical_time = 10
        self.__dnsserver_hostname = '1.1.1.1'
        self.__dnsserver_port = None
        self.__only_ipv4 = False
        self.__only_ipv6 = False
        self.__question = None
        self.__timeout = 10
        self.__record_type = 'A'
        self.__expected_address = 'set expected address!'
        self.__question_arguments = None
        self.set_check_interval('15m')
        self.add_service_group(ServiceGroup.create('dns'))
        self.add_service_group(ServiceGroup.create('dig'))
        self.add_service_group(ServiceGroup.create('network'))

    def set_warning_time(self, seconds):
        ValueChecker.is_number(seconds)
        self.__warning_time = seconds
        return self

    def get_warning_time(self):
        return self.__warning_time

    def set_critical_time(self, seconds):
        ValueChecker.is_number(seconds)
        self.__critical_time = seconds
        return self

    def get_critical_time(self):
        return self.__critical_time

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_question_arguments(self, arguments):
        ValueChecker.is_string(arguments)
        self.__question_arguments = arguments
        return self

    def get_question_arguments(self):
        return self.__question_arguments

    def set_expected_address(self, address):
        ValueChecker.is_string(address)
        self.__expected_address = address
        return self

    def get_expected_address(self):
        return self.__expected_address

    def set_record_type(self, type):
        ValueChecker.is_string(type)
        self.__record_type = type
        return self

    def get_record_type(self):
        return self.__record_type

    def set_question(self, address):
        ValueChecker.is_string(address)
        self.__question = address
        return self

    def get_question(self):
        return self.__question

    def set_dnsserver_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__dnsserver_hostname = hostname
        return self

    def get_dnsserver_hostname(self):
        return self.__dnsserver_hostname

    def set_dnsserver_port(self, port):
        ValueChecker.is_number(port)
        self.__dnsserver_port = port
        return self

    def get_dnsserver_port(self):
        return self.__dnsserver_port

    def set_only_ipv4(self, enabled):
        ValueChecker.is_number(enabled)
        self.__only_ipv4 = enabled
        return self

    def get_only_ipv4(self):
        return self.__only_ipv4

    def set_only_ipv6(self, enabled):
        ValueChecker.is_number(enabled)
        self.__only_ipv6 = enabled
        return self

    def get_only_ipv6(self):
        return self.__only_ipv6

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDig(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('dig'):
            DigCommand.create('dig')

        return check

    def validate(self):
        if None is self.__question:
            raise Exception('You have to specify a question for ' + self.get_id())
        if None is self.__record_type:
            raise Exception('You have to specify a record type for ' + self.get_id())
        if None is self.__expected_address:
            raise Exception('You have to specify an expected address for ' + self.get_id())
        if None is self.__warning_time:
            raise Exception('You have to specify a warning time for ' + self.get_id())
        if None is self.__critical_time:
            raise Exception('You have to specify a critical time for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.ValueMapper import ValueMapper

class ValueChecker:

    @staticmethod
    def get_prefixes():

        return [
            'server',
            'check',
            'template',
            'command',
            'vhost',
            'servicegroup',
            'hostgroup',
            'usergroup',
            'user',
            'ssh_template',
            'time_period',
            'notification_template',
            'notification',
            'downtime',
            'zone',
            'os',
            'package_manager',
        ]

    @staticmethod
    def validate_id(id):
        prefixes = ValueChecker.get_prefixes()

        for prefix in prefixes:
            if id.startswith(prefix + '_'):
                raise Exception(prefix + '_ is a reserved Prefix. You can\'t use it!')

        if ValueMapper.canonicalize_for_id(id) != id:
            raise Exception('Id\'s can only contains letters (a-z,A-Z), numbers (0-9) and underscore (_)')

    @staticmethod
    def is_bool(id):
        if not isinstance(id, bool):
            raise Exception('Given value is not boolean!')

    @staticmethod
    def is_number(id):
        if not isinstance(id, int) and not isinstance(id, float):
            raise Exception('Given value is not a number!')

    @staticmethod
    def is_string(id):
        if not isinstance(id, str):
            raise Exception('Given value is not a string!')

    @staticmethod
    def is_array(id):
        if not isinstance(id, list):
            raise Exception('Given value is not a list!')

    @staticmethod
    def is_http_method(id):
        if id not in ['GET', 'PUT', 'POST', 'DELETE', 'HEAD', 'OPTIONS', 'TRACE', 'CONNECT', 'PATCH']:
            raise Exception('Given value is not a HTTP method!')



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.OS.OS import OS
from icinga2confgen.PackageManager.PackageManager import rpm


def os_rhel_1(): return OS.create('rhel_1').set_distro('rhel').set_version('1').set_os(
    'Red Hat Enterprise Linux 1').append_package_manager(rpm())


def os_rhel_2(): return OS.create('rhel_2').set_distro('rhel').set_version('2').set_os(
    'Red Hat Enterprise Linux 2').append_package_manager(rpm())


def os_rhel_3(): return OS.create('rhel_3').set_distro('rhel').set_version('3').set_os(
    'Red Hat Enterprise Linux 3').append_package_manager(rpm())


def os_rhel_4(): return OS.create('rhel_4').set_distro('rhel').set_version('4').set_os(
    'Red Hat Enterprise Linux 4').append_package_manager(rpm())


def os_rhel_5(): return OS.create('rhel_5').set_distro('rhel').set_version('5').set_os(
    'Red Hat Enterprise Linux 5').append_package_manager(rpm())


def os_rhel_6(): return OS.create('rhel_6').set_distro('rhel').set_version('6').set_os(
    'Red Hat Enterprise Linux 6').append_package_manager(rpm())


def os_rhel_7(): return OS.create('rhel_7').set_distro('rhel').set_version('7').set_os(
    'Red Hat Enterprise Linux 7').append_package_manager(rpm())


def os_rhel_8(): return OS.create('rhel_8').set_distro('rhel').set_version('8').set_os(
    'Red Hat Enterprise Linux 8').append_package_manager(rpm())
